# -*- coding: utf-8 -*-
"""
This is the pyat package, one of the core modules for the NRAO archive workflow system

Authors:    Daniel K Lyons <dlyons@nrao.edu>
            Rick Lively <rlively@nrao.edu>
            James Sheckar <jsheckar@nrao.edu>
            Richard Falardeau <rfalarde@nrao.edu>
"""
import sys
import logging

LOG_MESSAGE_FORMATTER = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')


def get_console_logger(application_name, level=logging.INFO):
    r"""
    A function to build a console logger for the caller
    :param application_name: the callers name
    :param level: the log level to set, defaulting to INFO if not set
    :return: a console logger
    """
    console_log = logging.getLogger(application_name)
    console_log.setLevel(level)
    stdout_handler = logging.StreamHandler(sys.stdout)
    stdout_handler.setLevel(level)
    stdout_handler.setFormatter(LOG_MESSAGE_FORMATTER)
    console_log.addHandler(stdout_handler)
    return console_log


_LOG = get_console_logger(__name__, logging.DEBUG)
